==> 1.1.0.tar.gz: installer-prompt/src/installerprompt.h <==
#ifndef INSTALLERPROMPT_H
#define INSTALLERPROMPT_H

#include <QMainWindow>
#include <QComboBox>
#include <QProcess>
#include <QPushButton>
#include <QLabel>
#include <QDialog>
#include <QMutex>
#include <QLineEdit>
#include <QProcess>
#include <NetworkManagerQt/Device>
#include <NetworkManagerQt/WirelessDevice>
#include <NetworkManagerQt/WirelessNetwork>

namespace Ui { class InstallerPrompt; }

class InstallerPrompt : public QMainWindow {
    Q_OBJECT

public:
    explicit InstallerPrompt(QWidget *parent = nullptr);
    ~InstallerPrompt() override;

private slots:
    void refreshNetworkList();
    void onLanguageChanged(int index);
    void onLanguageConfirm();
    void onConnectWifiClicked();
    void updateConnectionStatus();
    void handleWiFiConnectionChange(NetworkManager::Device::State newstate, NetworkManager::Device::State oldstate, NetworkManager::Device::StateChangeReason reason);
    void tryLubuntu();
    void installLubuntu();
    void languageProcessFinished(int exitCode, QProcess::ExitStatus exitStatus);
    void languageProcessError(QProcess::ProcessError error);

private:
    Ui::InstallerPrompt *ui;
    QProcess *process;
    NetworkManager::WirelessDevice::Ptr wifiDevice;
    QString wifiSSID;
    QMutex wifiChangeMutex;
    NetworkManager::Connection::Ptr findConnectionBySsid(const QString &ssid);
    bool wifiWrongHandling = false;
    QLineEdit *passwordLineEdit;
    QMap<QString, QString> languageLocaleMap;
    QString selectedLanguage = "English (United States)";
    QString localeName = "en_US";

    void handleWifiConnection(const QString &ssid, bool recoverFromWrongPassword = false);
    QString promptForWifiPassword(const QString &ssid, bool isWrongPassword = false);
    void connectToWifi(const QString &ssid, const QString &password, bool recoverFromWrongPassword = false);
    void initLanguageComboBox();
    QStringList getAvailableLanguages();
    void showWifiOptions();
    NMVariantMapMap createSettingsBySSID(const QString &ssid);
};

#endif // INSTALLERPROMPT_H

==> 24.04.5.tar.gz: installer-prompt/src/installerprompt.h <==
#ifndef INSTALLERPROMPT_H
#define INSTALLERPROMPT_H

#include <QMainWindow>
#include <QComboBox>
#include <QProcess>
#include <QPushButton>
#include <QLabel>
#include <QDialog>
#include <QMutex>
#include <QLineEdit>
#include <QProcess>
#include <NetworkManagerQt/Device>
#include <NetworkManagerQt/WirelessDevice>
#include <NetworkManagerQt/WiredDevice>
#include <NetworkManagerQt/WirelessNetwork>

class ConnectionProgressDialog;

namespace Ui { class InstallerPrompt; }

class InstallerPrompt : public QMainWindow {
    Q_OBJECT

public:
    explicit InstallerPrompt(QWidget *parent = nullptr);
    ~InstallerPrompt() override;
    void activateBackground();

private slots:
    void onTryClicked();
    void onInstallClicked();
    void onLanguageSelected(int index);
    void onNetworkSelected(int index);
    void updateConnectionInfo();
    void handleWiFiConnectionChange(NetworkManager::Device::State newstate, NetworkManager::Device::State oldstate, NetworkManager::Device::StateChangeReason reason);
    void languageProcessError(QProcess::ProcessError error);

private:
    Ui::InstallerPrompt *ui;
    ConnectionProgressDialog *cpd;
    NetworkManager::WirelessDevice::Ptr wifiDevice;
    bool hitWifiDevice = false;
    QString wifiSsid;
    bool wifiWrongHandling = false;
    QMap<QString, QString> languageLocaleMap;
    bool firstUpdateConnectionInfoCall = true;

    void initLanguageComboBox();
    QStringList getAvailableLanguages();
    QString getDisplayNameForLocale(const QLocale &locale);
};

#endif // INSTALLERPROMPT_H
